==> qt6-declarative-6.0.0beta3-1-x86_64.pkg.tar.zst: usr/include/qt6/QtQuick/6.0.0/QtQuick/private/qquickrendercontrol_p.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtQuick module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QQUICKRENDERCONTROL_P_H
#define QQUICKRENDERCONTROL_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include "qquickrendercontrol.h"
#include <QtQuick/private/qsgcontext_p.h>

QT_BEGIN_NAMESPACE

class QRhi;
class QRhiCommandBuffer;
class QOffscreenSurface;

class Q_AUTOTEST_EXPORT QQuickRenderControlPrivate : public QObjectPrivate
{
public:
    Q_DECLARE_PUBLIC(QQuickRenderControl)

    QQuickRenderControlPrivate(QQuickRenderControl *renderControl);

    static QQuickRenderControlPrivate *get(QQuickRenderControl *renderControl) {
        return renderControl->d_func();
    }

    static void cleanup();

    void windowDestroyed();

    void update();
    void maybeUpdate();

    bool initRhi();
    void resetRhi();

    QImage grab();

    QQuickRenderControl *q;
    bool initialized;
    QQuickWindow *window;
    static QSGContext *sg;
    QSGRenderContext *rc;
    QRhi *rhi;
    QRhiCommandBuffer *cb;
    QOffscreenSurface *offscreenSurface;
    int sampleCount;
};

QT_END_NAMESPACE

#endif // QQUICKRENDERCONTROL_P_H

==> qt6-declarative-6.4.0beta1-1-x86_64.pkg.tar.zst: usr/include/qt6/QtQuick/6.4.0/QtQuick/private/qquickrendercontrol_p.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtQuick module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QQUICKRENDERCONTROL_P_H
#define QQUICKRENDERCONTROL_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include "qquickrendercontrol.h"
#include <QtQuick/private/qsgcontext_p.h>

QT_BEGIN_NAMESPACE

class QRhi;
class QRhiCommandBuffer;
class QOffscreenSurface;

class Q_QUICK_PRIVATE_EXPORT QQuickRenderControlPrivate : public QObjectPrivate
{
public:
    Q_DECLARE_PUBLIC(QQuickRenderControl)

    enum FrameStatus {
        NotRecordingFrame,
        RecordingFrame,
        DeviceLostInBeginFrame,
        ErrorInBeginFrame
    };

    QQuickRenderControlPrivate(QQuickRenderControl *renderControl);

    static QQuickRenderControlPrivate *get(QQuickRenderControl *renderControl) {
        return renderControl->d_func();
    }

    static bool isRenderWindowFor(QQuickWindow *quickWin, const QWindow *renderWin);
    virtual bool isRenderWindow(const QWindow *w) { Q_UNUSED(w); return false; }

    static void cleanup();

    void windowDestroyed();

    void update();
    void maybeUpdate();

    bool initRhi();
    void resetRhi();

    QImage grab();

    QQuickRenderControl *q;
    bool initialized;
    QQuickWindow *window;
    static QSGContext *sg;
    QSGRenderContext *rc;
    QRhi *rhi;
    bool ownRhi;
    QRhiCommandBuffer *cb;
    QOffscreenSurface *offscreenSurface;
    int sampleCount;
    FrameStatus frameStatus;
};

QT_END_NAMESPACE

#endif // QQUICKRENDERCONTROL_P_H
